# Downloads
[![Downloads](https://pepy.tech/badge/pony)](https://pepy.tech/project/pony) [![Downloads](https://pepy.tech/badge/pony/month)](https://pepy.tech/project/pony/month) [![Downloads](https://pepy.tech/badge/pony/week)](https://pepy.tech/project/pony/week)


Foal Object-Relational Mapper
=============================

FoalORM is an advanced object-relational mapper forked from PonyORM.

License
-------

FoalORM ORM is released under the MIT License.

This software includes the work that is distributed in the Apache License 2.0.
PonyORM: Copyright (c) 2013-2022 Pony ORM. https://github.com/ponyorm/pony
